Learn R Programming

wqtrends (version 1.5.1)

anlz_smooth: Return summary statistics for smoothers of GAMs

Description

Return summary statistics for smoothers of GAMs

Usage

anlz_smooth(mod)

Value

a data.frame with summary statistics for smoothers in each GAM

Arguments

mod

input model object as returned by anlz_gam

Details

Results show the individual effects of the modelled components of each model as the estimated degrees of freedom (edf), the reference degrees of freedom (Ref.df), the test statistic (F), and significance of the component (p-value). The significance of the component is in part based on the difference between edf and Ref.df.

Examples

Run this code
library(dplyr)

# data to model
tomod <- rawdat %>%
  filter(station %in% 34) %>%
  filter(param %in% 'chl')
  
mod <- anlz_gam(tomod, trans = 'log10')
anlz_smooth(mod)

Run the code above in your browser using DataLab