optional numeric vector for years to omit from the plot, see details
size
numeric indicating line size
alpha
numeric from 0 to 1 indicating line transparency
base_size
numeric indicating base font size, passed to theme_bw
Details
The optional yromit vector can be used to omit years from the plot. This may be preferred if the predicted values from the model deviate substantially from other years likely due to missing data.