- mod
input model object as returned by anlz_gam
- metfun
function input for metric to calculate, e.g., mean, var, max, etc
- doystr
numeric indicating start Julian day for extracting averages
- doyend
numeric indicating ending Julian day for extracting averages
- yrstr
numeric for starting year for trend model, see details
- yrend
numeric for ending year for trend model, see details
- yromit
optional numeric vector for years to omit from the plot, see details
- nsim
numeric indicating number of random draws for simulating uncertainty
- confint
numeric from zero to one indicating confidence interval level for summarizing the mixed-effects meta-analysis model, see details
- useave
logical indicating if anlz_avgseason is used for the seasonal metric calculation, see details
- ...
additional arguments passed to metfun, e.g., na.rm = TRUE